@@ -9,9 +9,11 @@ from time import sleep
 import argparse
 import sys
 import traceback
+import typing
+# from typing import Tuple, Optional, Hashable, TypeVar
 
 from . import applicationPath, settingsFile
-from .version import __version__
+from .version import __version__, __copyright__
 from .theme import (
     getGlobalFont,
     getGlobalTheme,
@@ -24,27 +26,27 @@ from .theme import (
 )
 from .examples import examplesList
 
-debugMode = False
-noEnumerationColumn = False
+debugMode: bool = False
+noEnumerationColumn: bool = False
 
-mainWindowID = "main-window"
-queryTextID = "query-text"
+mainWindowID: str = "main-window"
+queryTextID: str = "query-text"
 
-tabulateFloatfmtPrecision = "g"
+tabulateFloatfmtPrecision: str = "g"
 
 # Dear PyGui (and Dear ImGui) has a limitation of 64 columns in a table
 # https://dearpygui.readthedocs.io/en/latest/documentation/tables.html
 # https://github.com/ocornut/imgui/issues/2957#issuecomment-758136035
 # https://github.com/ocornut/imgui/pull/4876
-dpgColumnsMax = 64
+dpgColumnsMax: int = 64
 
-windowMinWidth = 900
+windowMinWidth: int = 900
 
-lastQueryResults = {}
-executingQuery = False
+lastQueryResults: pandas.DataFrame = pandas.DataFrame()
+executingQuery: bool = False
 
 
-def showLoading(isLoading):
+def showLoading(isLoading) -> None:
     global executingQuery
 
     if isLoading:
@@ -59,7 +61,7 @@ def showLoading(isLoading):
         executingQuery = False
 
 
-def keyPressCallback(sender, app_data):
+def keyPressCallback(sender, app_data) -> None:
     global executingQuery
 
     # print(sender, app_data)
@@ -79,9 +81,10 @@ def keyPressCallback(sender, app_data):
         executeQuery()
 
 
-def executeQuery():
+def executeQuery() -> None:
     global lastQueryResults
-    lastQueryResults = {}
+    # clear previously saved results
+    lastQueryResults = pandas.DataFrame()
 
     dpg.hide_item("resultsGroup")
     if dpg.does_item_exist("resultsTable"):
@@ -92,8 +95,8 @@ def executeQuery():
     dpg.configure_item("menuSaveFile", enabled=False)
     showLoading(True)
 
-    serviceURL = dpg.get_value("serviceURL").strip()
-    queryText = dpg.get_value(queryTextID).strip()
+    serviceURL: str = dpg.get_value("serviceURL").strip()
+    queryText: str = dpg.get_value(queryTextID).strip()
 
     if not serviceURL:
         dpg.set_value("errorMessage", "No service URL provided")
@@ -110,11 +113,13 @@ def executeQuery():
     if debugMode:
         print(f"\n[DEBUG] Query to execute:\n{queryText}")
 
-    results = {}
+    results: pyvo.dal.DALResults = {}
     try:
         service = pyvo.dal.TAPService(serviceURL)
         results = service.search(queryText)
     except Exception as ex:
+        if debugMode:
+            print(f"\n[DEBUG] Query failed: {ex}")
         dpg.set_value("errorMessage", ex)
         dpg.show_item("errorMessage")
         showLoading(False)
@@ -184,6 +189,8 @@ def executeQuery():
             for header in lastQueryResults:
                 dpg.add_table_column(label=header)
             for index, row in lastQueryResults.iterrows():
+                # reveal_type(index)
+                index = typing.cast(int, index)
                 with dpg.table_row():
                     if not noEnumerationColumn and rowsCount > 1:
                         with dpg.table_cell():
@@ -217,24 +224,24 @@ def executeQuery():
     dpg.configure_item("menuSaveFile", enabled=True)
 
 
-def preFillExample(sender, app_data, user_data):
+def preFillExample(sender, app_data, user_data) -> None:
     dpg.set_value("serviceURL", examplesList[user_data]["serviceURL"])
     dpg.set_value(queryTextID, examplesList[user_data]["queryText"])
 
 
-def saveResultsToPickle(sender, app_data, user_data):
+def saveResultsToPickle(sender, app_data, user_data) -> None:
     if debugMode:
         print(f"[DEBUG] {app_data}")
     # this check might be redundant,
     # as dialog window apparently performs it on its own
-    pickleFileDir = pathlib.Path(app_data["current_path"])
+    pickleFileDir: pathlib.Path = pathlib.Path(app_data["current_path"])
     if not pickleFileDir.is_dir():
         print(
             f"[ERROR] The {pickleFileDir} directory does not exist",
             file=sys.stderr
         )
         return
-    pickleFile = pickleFileDir / app_data["file_name"]
+    pickleFile: pathlib.Path = pickleFileDir / app_data["file_name"]
     try:
         lastQueryResults.to_pickle(pickleFile)
     except Exception as ex:
@@ -245,7 +252,7 @@ def saveResultsToPickle(sender, app_data, user_data):
         return
 
 
-def cellClicked(sender, app_data):
+def cellClicked(sender, app_data) -> None:
     # print(sender, app_data)
 
     # mouse right click
@@ -260,13 +267,13 @@ def cellClicked(sender, app_data):
         dpg.set_value(app_data[1], cellValue)
 
 
-def showDPGabout():
+def showDPGabout() -> None:
     # https://github.com/retifrav/tap-adql-sandbox/issues/6
     # dpg.hide_item("aboutWindow")
     dpg.show_about()
 
 
-def main():
+def main() -> None:
     global debugMode
     global tabulateFloatfmtPrecision
     global noEnumerationColumn
@@ -274,9 +281,9 @@ def main():
     argParser = argparse.ArgumentParser(
         prog="tap-adql-sandbox",
         description=" ".join((
-            "%(prog)s  Copyright (C) 2022  retif\nA",
+            f"%(prog)s\n{__copyright__}\nA",
             "sandbox application for executing ADQL queries",
-            "via TAP interface."
+            "via TAP interface"
         )),
         formatter_class=argparse.RawDescriptionHelpFormatter,
         allow_abbrev=False
@@ -404,6 +411,16 @@ def main():
                                 user_data=exmpl,
                                 callback=preFillExample
                             )
+                    with dpg.menu(label="Gaia"):
+                        for exmpl in {
+                            k: v for k, v in examplesList.items()
+                            if k.startswith("gaia-")
+                        }:
+                            dpg.add_menu_item(
+                                label=examplesList[exmpl]["description"],
+                                user_data=exmpl,
+                                callback=preFillExample
+                            )
                 dpg.add_spacer()
                 dpg.add_separator()
                 dpg.add_spacer()
@@ -501,19 +518,30 @@ def main():
         label="About application",
         # https://github.com/retifrav/tap-adql-sandbox/issues/6
         # modal=True,
+        min_size=(780, 380),
         show=False
     ):
         dpg.add_text(
             "".join((
                 "A sandbox application for executing ",
-                "ADQL queries via TAP interface\nof various data sources, ",
+                "ADQL queries via TAP interface\n",
+                "of various data sources, ",
                 "such as astronomical databases, using PyVO.\n",
                 "Essentially, this is a GUI for PyVO."
             ))
         )
+
         dpg.add_text(f"Version: {__version__}")
-        dpg.add_text("Source code: https://github.com/retifrav/tap-adql-sandbox")
-        dpg.add_text("License: GPLv3")
+
+        dpg.add_text(
+            "".join((
+                "License: GPLv3\n",
+                "Source code: https://github.com/retifrav/tap-adql-sandbox"
+            ))
+        )
+
+        dpg.add_text(__copyright__)
+
         dpg.add_spacer()
         dpg.add_separator()
         dpg.add_spacer(height=5)
@@ -583,5 +611,5 @@ def main():
     dpg.destroy_context()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
